# Symfem: a symbolic finite element definition library
[![Documentation status](https://readthedocs.org/projects/symfem/badge/?version=stable)](https://symfem.readthedocs.io/en/stable/?badge=stable)
![Style checks](https://github.com/mscroggs/symfem/workflows/.github/workflows/style-checks.yml/badge.svg)
![Run tests](https://github.com/mscroggs/symfem/workflows/.github/workflows/run-tests.yml/badge.svg)

## Installing Symfem
Symfem can be installed by downloading the [GitHub repo](https://github.com/mscroggs/symfem)
and running:

```bash
python3 setup.py install
```

Alternatively, the stable release can be installed by running:

```bash
pip3 install symfem
```

## Testing Symfem
To run the Symfem unit tests, clone the repository and run:

```bash
python3 -m pytest test/
```

## Using Symfem
Documentation of the latest release version of Symfem can be found on
[Read the Docs](https://symfem.readthedocs.io/en/stable/).

## Contributing to Symfem
You can find information about how to contribute to Symfem [here](CONTRIBUTING.md).
